@@ -6,7 +6,7 @@
 #
 
 my $project = "fetchmail";
-my $uploaddir = "branch_6.5";
+my $uploaddir = "branch_6.6";
 my $website = "https://downloads.sourceforge.net/project/$project/$uploaddir/";
 my $mailfrom = "<$project-devel\@lists.sourceforge.net> (Fetchmail Development Team)";
 my $xzsufx =	'.tar.xz';
@@ -26,13 +26,15 @@ die "Need GNU sort!" unless `sort --version | head -n1` =~ /GNU/;
 my $diffs = 0;
 my $verbose = 0;
 my $help = 0;
+my $dry_run = 0;
+
 my $null = ">/dev/null";
 my $errnull = "2>/dev/null";
 
 sub usage($$) {
     my ($own, $rc) = @_;
 
-    print STDERR "Usage: $_[0] [--verbose,-v] [--help,-h,-?]\n";
+    print STDERR "Usage: $_[0] [--verbose,-v] [--help,-h,-?] [--dry-run,-n]\n";
     exit($_[1]);
 }
 
@@ -49,7 +51,10 @@ sub makerelnotes($$) {
     close G or die "cannot write to $outfile: $!";
 }
 
-GetOptions("diffs|d" => \$diffs, "verbose|v" => \$verbose, "help|h|?" => \$help)
+GetOptions("diffs|d" => \$diffs,
+	   "verbose|v" => \$verbose,
+	   "help|h|?" => \$help,
+   	   "dry-run|n" => \$dry_run)
     or usage($0, 1);
 
 usage($0, 0) if $help;
@@ -63,8 +68,8 @@ if ($verbose) {
 my $tmp = $ENV{TMPDIR} || $ENV{TMP} || $ENV{TEMP} || "/tmp";
 
 # extract version from source
-my $version =`grep 'AC_INIT' configure.ac`;
-$version =~ /AC_INIT\([^,]*,\[?([0-9.rcbetalphdv-]+)\]?\,.*\)/;
+my $version =`grep 'version:' meson.build|head -n1`;
+$version =~ /version:.*'([0-9.rcbetalphdv-]+)'/;
 $version = $1;
 die "cannot determine version" unless defined $1;
 my $tag = "$version";
@@ -80,7 +85,7 @@ if ($tag !~ /[rcbetalph]/) {
 
 # extract existing tags
 my @versions;
-my $pattern = '6.5.*';
+my $pattern = '6.[56].*';
 open(ID, "git rev-list --topo-order --no-walk \$(git tag -l '$pattern' | grep -v rc) | xargs -tn1 git describe --match '$pattern' |") || die "cannot run git tag: $!\naborting";
 while (<ID>) {
 	chomp;
@@ -214,9 +219,19 @@ system("cd autobuild && gpg -ba --sign $project-$version$xzsufx");
 print "### Extracting release notes...\n";
 makerelnotes('NEWS', 'autobuild/README.txt');
 
-#die "Aborting... in dry-run mode";
+if ($dry_run) {
+    print "### Dry-run mode, not proceeding to upload.\n";
+    system("cat RELEASE-INSTRUCTIONS");
+    print "### Dry-run mode, not proceeding to upload.\n";
+    exit 0
+}
+
 print "### Uploading\n";
-print "=== local\n";
+print "=== GitLab\n";
+
+system("python dist-tools/gitlab-release.py 188557 $version autobuild/README.txt autobuild/$project-$version$xzsufx");
+
+print "=== SourceForge\n";
 
 system("rsync -acvHP autobuild/$project-$version$xzsufx autobuild/$project-$version$xzsufx.asc autobuild/README.txt m-a\@frs.sourceforge.net:/home/frs/project/fetchmail/$uploaddir/");
 # unlink 'autobuild/README' or die "cannot unlink autobuild/README: $!";
