@@ -14,10 +14,10 @@ exec podman run --rm -it \
 	fedora:rawhide \
 	sh -c "
 	dnf --setopt=keepcache=1 upgrade -y &&
-	dnf --setopt=keepcache=1 install automake awk bison flex $comppkg gettext-devel git openssl-devel -y &&
+	dnf --setopt=keepcache=1 install automake awk bison flex $comppkg gettext-devel git openssl-devel heimdal-devel -y &&
 	git clone --single-branch --branch '$branch' /gitrepo fetchmail &&
 	cd fetchmail &&
 	autoreconf -svi &&
-	./configure -C CC=$compiler CFLAGS='-Wall -Wextra -g -O2' &&
+	PATH=$PATH:/usr/lib/heimdal/bin ./configure -C CC=$compiler CFLAGS='-Wall -Wextra -g -O2' --with-gssapi &&
 	$pfx make -j$(nproc) check V=1 &&
 	./fetchmail -V"
